=========
chibi_lxc
=========


.. image:: https://img.shields.io/pypi/v/chibi_lxc.svg
        :target: https://pypi.python.org/pypi/chibi_lxc

.. image:: https://img.shields.io/travis/dem4ply/chibi_lxc.svg
        :target: https://travis-ci.org/dem4ply/chibi_lxc

.. image:: https://readthedocs.org/projects/chibi-lxc/badge/?version=latest
        :target: https://chibi-lxc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




definition of lxc containers using python


* Free software: WTFPL
* Documentation: https://chibi-lxc.readthedocs.io.


Features
--------

* TODO
